pub struct Decision<D: DecisionTrait> {
pub base_req: CompletionRequest,
pub best_of_n_votes: u8,
pub dynamic_temperature: bool,
pub reason: D,
pub result_can_be_none: bool,
}Fields
base_req: CompletionRequestbest_of_n_votes: u8dynamic_temperature: boolreason: Dresult_can_be_none: boolImplementations
Sourceimpl<D: DecisionTrait> Decision<D>
impl<D: DecisionTrait> Decision<D>
pub async fn return_primitive( &mut self, ) -> Result<<D::ReasonPrimitive as PrimitiveTrait>::PrimitiveResult>
pub async fn return_optional_primitive( &mut self, ) -> Result<Option<<D::ReasonPrimitive as PrimitiveTrait>::PrimitiveResult>>
pub async fn return_result(&mut self) -> Result<DecisionResult>
pub async fn return_optional_result(&mut self) -> Result<DecisionResult>
pub fn parse_decision_result( &self, decision_result: &DecisionResult, ) -> Result<Option<<D::ReasonPrimitive as PrimitiveTrait>::PrimitiveResult>>
Sourcepub fn best_of_n_votes(&mut self, best_of_n_votes: u8) -> &mut Self
pub fn best_of_n_votes(&mut self, best_of_n_votes: u8) -> &mut Self
Sets the number of votes to reach consensus. It is the maxium number of votes for a decision, but often the decision is reached before this number is reached.
For example, with the default of 3 votes, the first decision is made after 2 votes for a choice.
If given an even number, it will round up to the nearest odd number.
Sourcepub fn dynamic_temperature(&mut self, dynamic_temperature: bool) -> &mut Self
pub fn dynamic_temperature(&mut self, dynamic_temperature: bool) -> &mut Self
Dynamically scales temperature during the voting process. Starts at a low temperature and increases towards max temperature as the number of votes increases.